function [x,fvm,options]=rffmins(x,options,xobs,sigma,delay,fitdim,index)
%------------------------------------------------------------------------
%	df-sept-96	adopted/modified  from FMINS
%	simplex-based multi-variable minimization of CHI^2 (rfss.m)
%	for details see fmins.m (included in the standard Matlab library)
%	or type: help fmins 
%
% 	Copyright (c) 1996-97 by David Fushman, The Rockefeller University
%	calls: rfss.m
%------------------------------------------------------------------------
[dum,nobs]=size(xobs);
tol = options(2);
tol2 = options(3);
n = prod(size(x));
% Set up a simplex near the initial guess.
xin = x(:);
v = 0.9*xin;
x(:) = v; fv = rfss(x,xobs,sigma,delay,nobs,fitdim,index); 
for j = 1:n
   y = xin;
   if y(j) ~= 0
      y(j) = 1.1*y(j);
   else
      y(j) = 0.1;
   end
   v = [v y];
   x(:) = y; f = rfss(x,xobs,sigma,delay,nobs,fitdim,index);
   fv = [fv  f];
end
[fv,j] = sort(fv);
v = v(:,j);

cnt = n+1;


alpha = 1;  beta = 1/2;  gamma = 2;
[n,np1] = size(v);
onesn = ones(1,n); 
ot = 2:n+1;
on = 1:n;

% Iterate until the diameter of the simplex is less than tol.
while cnt < options(14)
    if max(max(abs(v(:,ot)-v(:,onesn)))) <= tol & ...
           max(abs(fv(1)-fv(ot))) <= tol2
        break
    end

    % One step of the Nelder-Mead simplex algorithm

    vbar = (sum(v(:,on)')/n)';
    vr = (1 + alpha)*vbar - alpha*v(:,n+1);
    x(:) = vr;
    fr = rfss(x,xobs,sigma,delay,nobs,fitdim,index);
    cnt = cnt + 1; 
    vk = vr;  fk = fr; how = 'reflect ';
    if fr < fv(n)
        if fr < fv(1)
            ve = gamma*vr + (1-gamma)*vbar;
            x(:) = ve;
            fe = rfss(x,xobs,sigma,delay,nobs,fitdim,index);
            cnt = cnt + 1;
            if fe < fv(1)
                vk = ve; fk = fe;
                how = 'expand  ';
            end
        end
    else
        vt = v(:,n+1); ft = fv(n+1);
        if fr < ft
            vt = vr; ft = fr;
        end
        vc = beta*vt + (1-beta)*vbar;
        x(:) = vc;
        fc = rfss(x,xobs,sigma,delay,nobs,fitdim,index);
        cnt = cnt + 1;
        if fc < fv(n)
            vk = vc; fk = fc;
            how = 'contract';
        else
            for j = 2:n
                v(:,j) = (v(:,1) + v(:,j))/2;
                x(:) = v(:,j);
                fv(j) = rfss(x,xobs,sigma,delay,nobs,fitdim,index);
            end
        cnt = cnt + n-1;
        vk = (v(:,1) + v(:,n+1))/2;
        x(:) = vk;
        fk = rfss(x,xobs,sigma,delay,nobs,fitdim,index);
        cnt = cnt + 1;
        how = 'shrink  ';
        end
    end
    v(:,n+1) = vk;
    fv(n+1) = fk;
    [fv,j] = sort(fv);
    v = v(:,j);
end
%-------------------final results---------------------
x= v(:,1)';
fvm=fv(1);
options(10)=cnt;
options(8)=min(fv); 
if cnt==options(14) 
    if options(1) >= 0
        disp(['Warning: Maximum number of iterations (', ...
               int2str(options(14)),') has been exceeded']);
        disp( '         (increase OPTIONS(14)).')
    end
end
return
%=============================================================
